<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../src/mainwindow.ui" line="14"/>
        <source>OpenSSH Authentication Passphrase request</source>
        <translation>Požadavek na ověření heslovou frází OpenSSH</translation>
    </message>
    <message>
        <location filename="../../src/mainwindow.ui" line="20"/>
        <source>Enter your SSH passphrase for request:</source>
        <translation>Zadejte heslovou frázi SSH:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../src/main.cpp" line="52"/>
        <source>unknown request</source>
        <translation>Neznámý požadavek</translation>
    </message>
</context>
</TS>
